<?php

namespace App\Controller;

use App\Entity\User;
use App\Traits\JsonResponseTrait;
use App\Repository\UserRepository;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\PasswordHasher\Hasher\UserPasswordHasherInterface;
use Lexik\Bundle\JWTAuthenticationBundle\Services\JWTTokenManagerInterface;

class AuthController extends AbstractController
{
    use JsonResponseTrait;

    public function __construct(private UserRepository $userRepository) {

    }

    #[Route('/api/register', methods: ["POST"], name: 'register')]
    public function register(Request $request, UserPasswordHasherInterface $encoder)
    {
        $em = $this->getDoctrine()->getManager();
        $name = $request->get('name');
        $surname = $request->get('surname');
        $password = $request->get('password');
        $email = $request->get('email');

        if (empty($name) || empty($password) || empty($email)){
            return $this->notAcceptable("Invalid Username or Password or Email");
        }

        $existing = $this->userRepository->findByEmail($email);
        if ($existing) {
            return $this->notAcceptable("User email exists");
        }

        $user = new User();
        $user->setPassword($encoder->hashPassword($user, $password));
        $user->setEmail($email);
        $user->setName($name);
        $user->setSurname($surname);
        $em->persist($user);
        $em->flush();
        return $this->created($user);
    }

    #[Route('/api/login', methods: ['POST'], name: 'login')]
    public function login(JWTTokenManagerInterface $JWTManager)
    {
        $user = new User();
        return $this->ok(['token' => $JWTManager->create($user)]);
    }

    #[Route('/api/user-check', methods: ['POST'])]
    public function checkUser() {
        $user = $this->getUser();
        if (!$user) {
            return $this->unauthorized([]);
        }
        $user->generateAvatar();
        return $this->ok($user);
    }
}
